@@ -40,12 +40,12 @@ class Base:
         self._verbose = verbose
         _internal = os.environ.get('internal', None) == "true"
         self._internal = _internal
-        _base_minio_url = _base_object_storage_url
+        self._base_minio_url = _base_object_storage_url
         if self._internal:
             base_discovery_api = _internal_base_discovery_api
         else:
             base_discovery_api = dataplatform_api_uri
-            _base_minio_url = object_storage_uri
+            self._base_minio_url = object_storage_uri
         self._base_discovery_api = base_discovery_api
         self._discovery_api = f"{base_discovery_api}/api/v2"
         
@@ -75,7 +75,7 @@ class Base:
         self._minio_secret = data['secret']
 
         self.client = Minio(
-            _base_minio_url,
+            self._base_minio_url,
             access_key=self._minio_access,
             secret_key=self._minio_secret,
             secure=not _internal
@@ -85,7 +85,7 @@ class Base:
             'key': self._minio_access,
             'secret': self._minio_secret,
             'client_kwargs':{
-                'endpoint_url': f"{_scheme}://{_base_minio_url}"
+                'endpoint_url': f"{_scheme}://{self._base_minio_url}"
             }
         }
         if self._verbose: print("Init DataNode sucessful!")
