@@ -61,9 +61,16 @@ class DataNode(DatasetManager):
         if _res.status_code != 201:
             raise Exception(f"can not create directory in discovery {_res.json()}")
         meta = _res.json()
+        
+        if 'append' in kwargs and kwargs['append']:
+            overwrite_parquet = False
+        else:
+            overwrite_parquet = True
+        
         df.to_parquet(f"s3://{bucket_name}/{meta['key']}",
             storage_options=self._storage_options,
             engine="pyarrow",
+            overwrite=overwrite_parquet,  # force delete old file
             **kwargs
         )
 
@@ -272,7 +279,7 @@ class DataNode(DatasetManager):
             return meta, io.BytesIO(response.data)
         
     
-    def read_ddf(self, file_id=None, index=0):
+    def read_ddf(self, file_id=None, index=0, extra_param=None):
         """_summary_
 
         Args:
@@ -295,16 +302,20 @@ class DataNode(DatasetManager):
         })
         _f_type = meta['type']['name']
         if _f_type == "parquet":
-            return dd.read_parquet(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
+            return dd.read_parquet(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options, **extra_param)
         elif _f_type == "csv":
-            return dd.read_csv(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options)
+            return dd.read_csv(f"s3://{bucket_name}/{meta['key']}", storage_options=self._storage_options, **extra_param)
         elif _f_type == "sql-query":
             r = requests.get(f"{self._base_discovery_api}/api/v2/file/{meta['id']}/getSqlQuery/", headers=self._jwt_header)
             check_http_status_code(r)
             r = requests.get(f"{self._base_discovery_api}/api/sql/query/{r.json()['id']}/", headers=self._jwt_header)
             check_http_status_code(r)
             data = r.json()
-            _database = DatabaseManagement(token=self.token)
+            _database = DatabaseManagement(
+                token=self.token, 
+                dataplatform_api_uri=self._base_discovery_api,
+                object_storage_uri=self._base_minio_url,
+            )
             database_id = data['database']
             database_meta, schema = _database.get_database_schema(database_id=database_id)
             
